﻿' *****************************************************************
' *                                                               *
' *       Copyright (c) Fast Corporation, 2024                    *
' *                                                               *
' *   All Rights Reserved.  Unpublished rights  reserved  under   *
' *   the copyright laws of the Japan.                            *
' *                                                               *
' *   The software contained on this media  is  proprietary  to   *
' *   and  embodies  the  confidential  technology  of  Fast      *
' *   Corporation.  Possession, use,  duplication  or             *
' *   dissemination of the software and media is authorized only  *
' *   pursuant to a valid written license from Fast Corporation.  *
' *                                                               *
' *****************************************************************

' -----------------------------------------------------------------
' FVIL Sample Program
' メインダイアログ
'
' 作成者 : N.Moriguchi
'
' 履歴 : 2024/03/06 初版
'
' PolarTrans Sample Program
' -----------------------------------------------------------------
Public Class PolarTrans

    '極座標変換クラス
    Private m_PolarTrans As FVIL.PolarTrans.CFviPolarTrans = New FVIL.PolarTrans.CFviPolarTrans()
    '極座標変換パラメータ構造クラス
    Private m_PolarTransParam As FVIL.PolarTrans.CFviPolarTransParam = New FVIL.PolarTrans.CFviPolarTransParam()

    '入力画像
    Private m_SrcImage As FVIL.Data.CFviImage = New FVIL.Data.CFviImage()
    '変換後画像
    Private m_DstImage As FVIL.Data.CFviImage = New FVIL.Data.CFviImage()

    ''' <summary>
    ''' フォーム表示開始 イベントハンドラ
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 使用許諾を確認します。
    ''' </remarks>
    Private Sub PolarTrans_Shown(sender As Object, e As EventArgs) Handles MyBase.Shown
        '使用許諾の確認
        Dim licence_dialog As New dialogLicence
        If (licence_dialog.ShowDialog(Me) <> System.Windows.Forms.DialogResult.OK) Then
            Me.Close() '使用許諾が得られない場合はサンプルプログラムの動作を終了
            Exit Sub
        End If
    End Sub

    ''' <summary>
    ''' メインフォーム初期化
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' メインフォームの初期化処理。
    ''' </remarks>
    Private Sub Form1_Load(sender As Object, e As EventArgs) Handles MyBase.Load
        'FVILの初期化
        'アプリケーションを起動した後、 この関数を呼び出してライブラリを初期化してください。 
        'この時、ライセンスの認証が行われます。試用期間中であっても、この処理は必ず行う必要が有ります。 
        '初期化を行わなかった場合は、プロテクトされたクラスの実行ができません。
        FVIL._SetUp.InitVisionLibrary()

        'パラメータ初期値設定
        '変換方向
        m_PolarTrans.Invert = False     'false:矩形→円形
        ComboBoxInvert.Items.Clear()
        ComboBoxInvert.Items.Add("矩形 → 円形")
        ComboBoxInvert.Items.Add("円形 → 矩形")
        ComboBoxInvert.SelectedIndex = 0

        '背景処理
        m_PolarTrans.ClearBackMode = True   'true:0クリアする
        ComboBoxClearBack.Items.Clear()
        ComboBoxClearBack.Items.Add("0クリアする")
        ComboBoxClearBack.Items.Add("処理しない")
        ComboBoxClearBack.SelectedIndex = 0

        '濃度補間方法
        m_PolarTrans.SamplingMode = FVIL.PolarTrans.SamplingMode.NearestNeighbor
        ComboBoxSamplingMode.Items.Clear()
        ComboBoxSamplingMode.Items.Add("NearestNeighbor")
        ComboBoxSamplingMode.Items.Add("Bilinear")
        ComboBoxSamplingMode.Items.Add("Cubic")
        ComboBoxSamplingMode.SelectedIndex = 0

        '基準座標モード
        m_PolarTrans.Param.CoordinateMode = FVIL.PolarTrans.CoordinateMode.Left
        ComboBoxCoordinateMode.Items.Clear()
        ComboBoxCoordinateMode.Items.Add("Upper(右上)")
        ComboBoxCoordinateMode.Items.Add("Lower(左下)")
        ComboBoxCoordinateMode.Items.Add("Left(左上)")
        ComboBoxCoordinateMode.Items.Add("Right(右下)")
        ComboBoxCoordinateMode.SelectedIndex = 2

        '極座標変換パラメータの設定
        m_PolarTransParam = m_PolarTrans.Param

        '矩形領域の基準座標
        m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint(m_PolarTransParam.Width, m_PolarTransParam.Width)
        TextBoxOriginInX.Text = m_PolarTransParam.OriginIn.X.ToString("0.0")
        TextBoxOriginInY.Text = m_PolarTransParam.OriginIn.Y.ToString("0.0")

        '矩形領域サイズ
        m_PolarTransParam.Width = m_SrcImage.Window.Width
        m_PolarTransParam.Height = m_SrcImage.Window.Height
        NumericUpDownWidth.Value = m_PolarTransParam.Width
        NumericUpDownHeight.Value = m_PolarTransParam.Height

        '円形領域の回転中心座標
        m_PolarTransParam.OriginOut = New FVIL.Data.CFviPoint(m_PolarTransParam.Width, m_PolarTransParam.Width)
        TextBoxOriginOutX.Text = m_PolarTransParam.OriginOut.X.ToString("0.0")
        TextBoxOriginOutY.Text = m_PolarTransParam.OriginOut.Y.ToString("0.0")

        '円形領域の半径
        m_PolarTransParam.Radius = m_PolarTransParam.Width
        NumericUpDownRadius.Value = m_PolarTransParam.Radius

        '円形領域の回転開始角度
        m_PolarTransParam.StartAngle = New FVIL.Data.CFviAngle(270.0)
        TextBoxStartAngle.Text = m_PolarTransParam.StartAngle.Degree.ToString("0.0")

        '円形領域の回転範囲
        m_PolarTransParam.RangeAngle = New FVIL.Data.CFviAngle(360.0)
        TextBoxRangeAngle.Text = m_PolarTransParam.RangeAngle.Degree.ToString("0.0")
    End Sub

    ''' <summary>
    ''' Load Fileボタン
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 入力画像ファイルのロード。
    ''' </remarks>
    Private Sub ButtonLoadFile_Click(sender As Object, e As EventArgs) Handles ButtonLoadFile.Click
        '入力画像ファイルのロード
        OpenFileDialog1.FileName = ""
        OpenFileDialog1.Filter = "Bitmap ファイル (*.bmp;*.dib)|*.bmp;*.dib"
        OpenFileDialog1.Filter += "|Png ファイル (*.png)|*.png"
        OpenFileDialog1.Filter += "|Jpeg ファイル (*.jpg;*.jpeg)|*.jpg;*.jpeg"
        OpenFileDialog1.Filter += "|Tiff ファイル (*.tif;*.tiff)|*.tif;*.tiff"
        OpenFileDialog1.DefaultExt = "*.bmp"
        If ((OpenFileDialog1.FileNames.Length <= 0) Or (OpenFileDialog1.ShowDialog(Me) = System.Windows.Forms.DialogResult.Cancel)) Then
            Return
        End If

        Try
            FVIL.File.Function.LoadImageFile(OpenFileDialog1.FileName, m_SrcImage, FVIL.PixelMode.Unpacking)
        Catch ex As FVIL.CFviException
            'エラー処理
            MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        Catch ex As Exception
            'エラー処理
            MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try

        '描画imageのセット
        CFviImageView1.Image = m_SrcImage
        RadioButtonDisplaySrc.Checked = True

        'パラメータ更新
        Select Case ComboBoxCoordinateMode.SelectedIndex
            Case 0
                'Upper(右上)
                If (ComboBoxInvert.SelectedIndex = 0) Then
                    '矩形 → 円形
                    '矩形領域の基準座標
                    m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Y)
                    TextBoxOriginInX.Text = m_SrcImage.Window.Width.ToString("0.0")
                    TextBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0")
                    '円形領域の回転中心座標
                    m_PolarTransParam.OriginOut = New FVIL.Data.CFviPoint(m_SrcImage.Window.Height, m_SrcImage.Window.Height)
                    TextBoxOriginOutX.Text = m_SrcImage.Window.Height.ToString("0.0")
                    TextBoxOriginOutY.Text = m_SrcImage.Window.Height.ToString("0.0")
                    '円形領域の半径
                    m_PolarTransParam.Radius = m_SrcImage.Window.Height
                    NumericUpDownRadius.Value = m_SrcImage.Window.Height
                Else
                    '円形 → 矩形
                    '矩形領域の基準座標
                    m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint((m_SrcImage.Window.Width / 2), m_SrcImage.Window.Y)
                    TextBoxOriginInX.Text = (m_SrcImage.Window.Width / 2).ToString("0.0")
                    TextBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0")
                End If
            Case 1
                'Lower(左下)
                If (ComboBoxInvert.SelectedIndex = 0) Then
                    '矩形 → 円形
                    '矩形領域の基準座標
                    m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint(m_SrcImage.Window.X, m_SrcImage.Window.Height)
                    TextBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0")
                    TextBoxOriginInY.Text = m_SrcImage.Window.Height.ToString("0.0")
                    '円形領域の回転中心座標
                    m_PolarTransParam.OriginOut = New FVIL.Data.CFviPoint(m_SrcImage.Window.Height, m_SrcImage.Window.Height)
                    TextBoxOriginOutX.Text = m_SrcImage.Window.Height.ToString("0.0")
                    TextBoxOriginOutY.Text = m_SrcImage.Window.Height.ToString("0.0")
                    '円形領域の半径
                    m_PolarTransParam.Radius = m_SrcImage.Window.Height
                    NumericUpDownRadius.Value = m_SrcImage.Window.Height
                Else
                    '円形 → 矩形
                    '矩形領域の基準座標
                    m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint(m_SrcImage.Window.X, (m_SrcImage.Window.Width / 2))
                    TextBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0")
                    TextBoxOriginInY.Text = (m_SrcImage.Window.Width / 2).ToString("0.0")
                End If
            Case 2
                'Left(左上)
                If (ComboBoxInvert.SelectedIndex = 0) Then
                    '矩形 → 円形
                    '矩形領域の基準座標
                    m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint(m_SrcImage.Window.X, m_SrcImage.Window.Y)
                    TextBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0")
                    TextBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0")
                    '円形領域の回転中心座標
                    m_PolarTransParam.OriginOut = New FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Width)
                    TextBoxOriginOutX.Text = m_SrcImage.Window.Width.ToString("0.0")
                    TextBoxOriginOutY.Text = m_SrcImage.Window.Width.ToString("0.0")
                    '円形領域の半径
                    m_PolarTransParam.Radius = m_SrcImage.Window.Width
                    NumericUpDownRadius.Value = m_SrcImage.Window.Width
                Else
                    '円形 → 矩形
                    '矩形領域の基準座標
                    m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint(m_SrcImage.Window.X, m_SrcImage.Window.Y)
                    TextBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0")
                    TextBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0")
                End If
            Case 3
                'Right(右下)
                If (ComboBoxInvert.SelectedIndex = 0) Then
                    '矩形 → 円形
                    '矩形領域の基準座標
                    m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Height)
                    TextBoxOriginInX.Text = m_SrcImage.Window.Width.ToString("0.0")
                    TextBoxOriginInY.Text = m_SrcImage.Window.Height.ToString("0.0")
                    '円形領域の回転中心座標
                    m_PolarTransParam.OriginOut = New FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Width)
                    TextBoxOriginOutX.Text = m_SrcImage.Window.Width.ToString("0.0")
                    TextBoxOriginOutY.Text = m_SrcImage.Window.Width.ToString("0.0")
                    '円形領域の半径
                    m_PolarTransParam.Radius = m_SrcImage.Window.Width
                    NumericUpDownRadius.Value = m_SrcImage.Window.Width
                Else
                    '円形 → 矩形
                    '矩形領域の基準座標
                    m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint((m_SrcImage.Window.Width / 2), (m_SrcImage.Window.Width / 2))
                    TextBoxOriginInX.Text = (m_SrcImage.Window.Width / 2).ToString("0.0")
                    TextBoxOriginInY.Text = (m_SrcImage.Window.Width / 2).ToString("0.0")
                End If
        End Select

        If (ComboBoxInvert.SelectedIndex = 0) Then
            '矩形 → 円形
            '矩形領域サイズ
            m_PolarTransParam.Width = m_SrcImage.Window.Width
            NumericUpDownWidth.Value = m_SrcImage.Window.Width
            m_PolarTransParam.Height = m_SrcImage.Window.Height
            NumericUpDownHeight.Value = m_SrcImage.Window.Height
        Else
            '円形 → 矩形
            '矩形領域サイズ
            m_PolarTransParam.Width = (m_SrcImage.Window.Width / 2)
            NumericUpDownWidth.Value = (m_SrcImage.Window.Width / 2)
            m_PolarTransParam.Height = (m_SrcImage.Window.Height / 2)
            NumericUpDownHeight.Value = (m_SrcImage.Window.Height / 2)
            '円形領域の回転中心座標
            m_PolarTransParam.OriginOut = New FVIL.Data.CFviPoint((m_SrcImage.Window.Width / 2), (m_SrcImage.Window.Height / 2))
            TextBoxOriginOutX.Text = (m_SrcImage.Window.Width / 2).ToString("0.0")
            TextBoxOriginOutY.Text = (m_SrcImage.Window.Height / 2).ToString("0.0")
            '円形領域の半径
            m_PolarTransParam.Radius = (m_SrcImage.Window.Width / 2)
            NumericUpDownRadius.Value = (m_SrcImage.Window.Width / 2)
        End If

        '再描画
        CFviImageView1.Refresh()
    End Sub

    ''' <summary>
    ''' 極座標変換実行ボタン
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 極座標変換処理。
    ''' </remarks>
    Private Sub ButtonExecute_Click(sender As Object, e As EventArgs) Handles ButtonExecute.Click
        Try
            '処理対象画像の有効性検査
            Dim valid As Integer
            valid = FVIL.PolarTrans.CFviPolarTrans.CheckValidity(m_SrcImage)
            If (valid <> FVIL.ErrorCode._SUCCESS) Then
                MessageBox.Show("入力画像が不正です", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
                Return
            End If

            '画像準備
            m_PolarTrans.SrcImages(0) = m_SrcImage
            m_PolarTrans.DstImages(0) = m_DstImage

            '出力画像の有効化
            m_PolarTrans.Validate(1)

            '極座標変換実行
            m_PolarTrans.Execute()

            '出力画像のセット
            CFviImageView1.Image = m_DstImage
            RadioButtonDisplayDst.Checked = True
            '再描画
            CFviImageView1.Refresh()
        Catch ex As FVIL.CFviException
            'エラー処理
            MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        Catch ex As Exception
            'エラー処理
            MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
    End Sub

    ''' <summary>
    ''' Save Imageボタン
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 表示画像保存。
    ''' </remarks>
    Private Sub ButtonSaveImage_Click(sender As Object, e As EventArgs) Handles ButtonSaveImage.Click
        Dim ofdlg As SaveFileDialog = New SaveFileDialog()
        ofdlg.Filter = "画像ファイル(*.bmp;*.dib;*.png;*.jpg;*.jpeg;*.tif;*.tiff;*.raw;*.pat)|*.bmp;*.dib;*.png;*.jpg;*.jpeg;*.tif;*.tiff;*.raw;*.pat"
        ofdlg.Filter += "|Bitmap ファイル (*.bmp;*.dib)|*.bmp;*.dib"
        ofdlg.Filter += "|Png ファイル (*.png)|*.png"
        ofdlg.Filter += "|Jpeg ファイル (*.jpg;*.jpeg)|*.jpg;*.jpeg"
        ofdlg.Filter += "|Tiff ファイル (*.tif;*.tiff)|*.tif;*.tiff"
        ofdlg.Filter += "|Raw ファイル (*.raw)|*.raw"
        ofdlg.Filter += "|すべてのファイル (*.*)|*.*"
        ofdlg.OverwritePrompt = True

        If (ofdlg.ShowDialog(Me) = System.Windows.Forms.DialogResult.OK) Then
            Try
                'この関数は、簡易的に画像ファイルの保存を行う為のものです。 
                'この関数で指定できないパラメータを指定する必要があれば、 各画像ファイルアクセスクラスを直接使用してください。 
                FVIL.File.Function.SaveImageFile(ofdlg.FileName, CFviImageView1.Image)

                '保存するファイル形式が固定の場合は、以下のように記述します。
                '例1) bmpファイルの場合
                'Dim file As FVIL.File.CFviImageFileBmp = New FVIL.File.CFviImageFileBmp()
                'file.Save(ofdlg.FileName, m_image)

                '例2) jpgファイルの場合
                'Dim file As FVIL.File.CFviImageFileJpg = New FVIL.File.CFviImageFileJpg()
                'file.Save(ofdlg.FileName, m_image)
            Catch ex As FVIL.CFviException
                Dim msg As System.String = System.String.Format("ライブラリが例外を発行しました。code={0} func={1}", ex.ErrorCode, ex.Function)
                Select Case (ex.ErrorCode)
                    Case FVIL.ErrorCode.NOT_SUPPORTED,
                     FVIL.ErrorCode.INVALID_OBJECT
                        msg += vbCrLf + "サポートされていない画像オブジェクトです。"
                        msg += vbCrLf + "Raw 形式で保存してください。"
                End Select
                MessageBox.Show(msg, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
            Catch ex As Exception
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
            End Try
        End If
    End Sub

    ''' <summary>
    ''' 表示画像切替えラジオボタン
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 入力画像を表示します。
    ''' </remarks>
    Private Sub RadioButtonDisplaySrc_CheckedChanged(sender As Object, e As EventArgs) Handles RadioButtonDisplaySrc.CheckedChanged
        '入力画像のセット
        CFviImageView1.Image = m_SrcImage
        '再描画
        CFviImageView1.Refresh()
    End Sub

    ''' <summary>
    ''' 表示画像切替えラジオボタン
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 出力画像を表示します。
    ''' </remarks>
    Private Sub RadioButtonDisplayDst_CheckedChanged(sender As Object, e As EventArgs) Handles RadioButtonDisplayDst.CheckedChanged
        '出力画像セット
        CFviImageView1.Image = m_DstImage
        '再描画
        CFviImageView1.Refresh()
    End Sub

    ''' <summary>
    ''' 変換方向の反転フラグ
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 通常方向(false)・逆方向(true)の選択。
    ''' </remarks>
    Private Sub ComboBoxInvert_SelectedIndexChanged(sender As Object, e As EventArgs) Handles ComboBoxInvert.SelectedIndexChanged
        Try
            If (ComboBoxInvert.SelectedIndex = 0) Then
                '矩形→円形
                m_PolarTrans.Invert = False
                'パラメータ更新
                Select Case ComboBoxCoordinateMode.SelectedIndex
                    Case 0
                        'Upper(右上)
                        '矩形領域の基準座標
                        m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Y)
                        TextBoxOriginInX.Text = m_SrcImage.Window.Width.ToString("0.0")
                        TextBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0")
                        '円形領域の回転中心座標
                        m_PolarTransParam.OriginOut = New FVIL.Data.CFviPoint(m_SrcImage.Window.Height, m_SrcImage.Window.Height)
                        TextBoxOriginOutX.Text = m_SrcImage.Window.Height.ToString("0.0")
                        TextBoxOriginOutY.Text = m_SrcImage.Window.Height.ToString("0.0")
                        '円形領域の半径
                        m_PolarTransParam.Radius = m_SrcImage.Window.Height
                        NumericUpDownRadius.Value = m_SrcImage.Window.Height
                    Case 1
                        'Lower(左下)
                        '矩形領域の基準座標
                        m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint(m_SrcImage.Window.X, m_SrcImage.Window.Height)
                        TextBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0")
                        TextBoxOriginInY.Text = m_SrcImage.Window.Height.ToString("0.0")
                        '円形領域の回転中心座標
                        m_PolarTransParam.OriginOut = New FVIL.Data.CFviPoint(m_SrcImage.Window.Height, m_SrcImage.Window.Height)
                        TextBoxOriginOutX.Text = m_SrcImage.Window.Height.ToString("0.0")
                        TextBoxOriginOutY.Text = m_SrcImage.Window.Height.ToString("0.0")
                        '円形領域の半径
                        m_PolarTransParam.Radius = m_SrcImage.Window.Height
                        NumericUpDownRadius.Value = m_SrcImage.Window.Height
                    Case 2
                        'Left(左上)
                        '矩形領域の基準座標
                        m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint(m_SrcImage.Window.X, m_SrcImage.Window.Y)
                        TextBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0")
                        TextBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0")
                        '円形領域の回転中心座標
                        m_PolarTransParam.OriginOut = New FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Width)
                        TextBoxOriginOutX.Text = m_SrcImage.Window.Width.ToString("0.0")
                        TextBoxOriginOutY.Text = m_SrcImage.Window.Width.ToString("0.0")
                        '円形領域の半径
                        m_PolarTransParam.Radius = m_SrcImage.Window.Width
                        NumericUpDownRadius.Value = m_SrcImage.Window.Width
                    Case 3
                        'Right(右下)
                        '矩形領域の基準座標
                        m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Height)
                        TextBoxOriginInX.Text = m_SrcImage.Window.Width.ToString("0.0")
                        TextBoxOriginInY.Text = m_SrcImage.Window.Height.ToString("0.0")
                        '円形領域の回転中心座標
                        m_PolarTransParam.OriginOut = New FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Width)
                        TextBoxOriginOutX.Text = m_SrcImage.Window.Width.ToString("0.0")
                        TextBoxOriginOutY.Text = m_SrcImage.Window.Width.ToString("0.0")
                        '円形領域の半径
                        m_PolarTransParam.Radius = m_SrcImage.Window.Width
                        NumericUpDownRadius.Value = m_SrcImage.Window.Width
                End Select
                '矩形領域サイズ
                m_PolarTransParam.Width = m_SrcImage.Window.Width
                NumericUpDownWidth.Value = m_SrcImage.Window.Width
                m_PolarTransParam.Height = m_SrcImage.Window.Height
                NumericUpDownHeight.Value = m_SrcImage.Window.Height
            Else
                '円形→矩形
                m_PolarTrans.Invert = True
                'パラメータ更新
                Select Case ComboBoxCoordinateMode.SelectedIndex
                    Case 0
                        'Upper(右上)
                        '矩形領域の基準座標
                        m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint((m_SrcImage.Window.Width / 2), m_SrcImage.Window.Y)
                        TextBoxOriginInX.Text = (m_SrcImage.Window.Width / 2).ToString("0.0")
                        TextBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0")
                    Case 1
                        'Lower(左下)
                        '矩形領域の基準座標
                        m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint(m_SrcImage.Window.X, (m_SrcImage.Window.Width / 2))
                        TextBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0")
                        TextBoxOriginInY.Text = (m_SrcImage.Window.Width / 2).ToString("0.0")
                    Case 2
                        'Left(左上)
                        '矩形領域の基準座標
                        m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint(m_SrcImage.Window.X, m_SrcImage.Window.Y)
                        TextBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0")
                        TextBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0")
                    Case 3
                        'Right(右下)
                        '矩形領域の基準座標
                        m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint((m_SrcImage.Window.Width / 2), (m_SrcImage.Window.Width / 2))
                        TextBoxOriginInX.Text = (m_SrcImage.Window.Width / 2).ToString("0.0")
                        TextBoxOriginInY.Text = (m_SrcImage.Window.Width / 2).ToString("0.0")
                End Select
                '矩形領域サイズ
                m_PolarTransParam.Width = (m_SrcImage.Window.Width / 2)
                NumericUpDownWidth.Value = (m_SrcImage.Window.Width / 2)
                m_PolarTransParam.Height = (m_SrcImage.Window.Height / 2)
                NumericUpDownHeight.Value = (m_SrcImage.Window.Height / 2)
                '円形領域の回転中心座標
                m_PolarTransParam.OriginOut = New FVIL.Data.CFviPoint((m_SrcImage.Window.Width / 2), (m_SrcImage.Window.Height / 2))
                TextBoxOriginOutX.Text = (m_SrcImage.Window.Width / 2).ToString("0.0")
                TextBoxOriginOutY.Text = (m_SrcImage.Window.Height / 2).ToString("0.0")
                '円形領域の半径
                m_PolarTransParam.Radius = (m_SrcImage.Window.Width / 2)
                NumericUpDownRadius.Value = (m_SrcImage.Window.Width / 2)
            End If
        Catch ex As FVIL.CFviException
            'エラー処理
            MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        Catch ex As Exception
            'エラー処理
            MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
    End Sub

    ''' <summary>
    ''' 領域外画素の処理方法
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' ０クリア(true)・処理しない(false)の選択。
    ''' </remarks>
    Private Sub ComboBoxClearBack_SelectedIndexChanged(sender As Object, e As EventArgs) Handles ComboBoxClearBack.SelectedIndexChanged
        Try
            Select Case ComboBoxClearBack.SelectedIndex
                Case 0
                    '0クリアする
                    m_PolarTrans.ClearBackMode = True
                Case 1
                    '処理しない
                    m_PolarTrans.ClearBackMode = False
            End Select
        Catch ex As FVIL.CFviException
            'エラー処理
            MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        Catch ex As Exception
            'エラー処理
            MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
    End Sub

    ''' <summary>
    ''' 濃度補間方法
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' NearestNeighbor・Bilinear・Cubicの選択。
    ''' </remarks>
    Private Sub ComboBoxSamplingMode_SelectedIndexChanged(sender As Object, e As EventArgs) Handles ComboBoxSamplingMode.SelectedIndexChanged
        Try
            Select Case ComboBoxSamplingMode.SelectedIndex
                Case 0
                    'NearestNeighbor
                    m_PolarTrans.SamplingMode = FVIL.PolarTrans.SamplingMode.NearestNeighbor
                Case 1
                    'Bilinear
                    m_PolarTrans.SamplingMode = FVIL.PolarTrans.SamplingMode.Bilinear
                Case 2
                    'Cubic
                    m_PolarTrans.SamplingMode = FVIL.PolarTrans.SamplingMode.Cubic
            End Select
        Catch ex As FVIL.CFviException
            'エラー処理
            MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        Catch ex As Exception
            'エラー処理
            MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
    End Sub

    ''' <summary>
    ''' 基準座標モード
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' Upper・Lower・Left・Rightの選択。
    ''' </remarks>
    Private Sub ComboBoxCoordinateMode_SelectedIndexChanged(sender As Object, e As EventArgs) Handles ComboBoxCoordinateMode.SelectedIndexChanged
        Try
            Select Case ComboBoxCoordinateMode.SelectedIndex
                Case 0
                    'Upper(右上)
                    m_PolarTrans.Param.CoordinateMode = FVIL.PolarTrans.CoordinateMode.Upper
                    If (ComboBoxInvert.SelectedIndex = 0) Then
                        '矩形 → 円形
                        '矩形領域の基準座標
                        m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Y)
                        TextBoxOriginInX.Text = m_SrcImage.Window.Width.ToString("0.0")
                        TextBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0")
                        '円形領域の回転中心座標
                        m_PolarTransParam.OriginOut = New FVIL.Data.CFviPoint(m_SrcImage.Window.Height, m_SrcImage.Window.Height)
                        TextBoxOriginOutX.Text = m_SrcImage.Window.Height.ToString("0.0")
                        TextBoxOriginOutY.Text = m_SrcImage.Window.Height.ToString("0.0")
                        '円形領域の半径
                        m_PolarTransParam.Radius = m_SrcImage.Window.Height
                        NumericUpDownRadius.Value = m_SrcImage.Window.Height
                    Else
                        '円形 → 矩形
                        '矩形領域の基準座標
                        m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint((m_SrcImage.Window.Width / 2), m_SrcImage.Window.Y)
                        TextBoxOriginInX.Text = (m_SrcImage.Window.Width / 2).ToString("0.0")
                        TextBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0")
                    End If
                Case 1
                    'Lower(左下)
                    m_PolarTrans.Param.CoordinateMode = FVIL.PolarTrans.CoordinateMode.Lower
                    If (ComboBoxInvert.SelectedIndex = 0) Then
                        '矩形 → 円形
                        '矩形領域の基準座標
                        m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint(m_SrcImage.Window.X, m_SrcImage.Window.Height)
                        TextBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0")
                        TextBoxOriginInY.Text = m_SrcImage.Window.Height.ToString("0.0")
                        '円形領域の回転中心座標
                        m_PolarTransParam.OriginOut = New FVIL.Data.CFviPoint(m_SrcImage.Window.Height, m_SrcImage.Window.Height)
                        TextBoxOriginOutX.Text = m_SrcImage.Window.Height.ToString("0.0")
                        TextBoxOriginOutY.Text = m_SrcImage.Window.Height.ToString("0.0")
                        '円形領域の半径
                        m_PolarTransParam.Radius = m_SrcImage.Window.Height
                        NumericUpDownRadius.Value = m_SrcImage.Window.Height
                    Else
                        '円形 → 矩形
                        '矩形領域の基準座標
                        m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint(m_SrcImage.Window.X, (m_SrcImage.Window.Width / 2))
                        TextBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0")
                        TextBoxOriginInY.Text = (m_SrcImage.Window.Width / 2).ToString("0.0")
                    End If
                Case 2
                    'Left(左上)
                    m_PolarTrans.Param.CoordinateMode = FVIL.PolarTrans.CoordinateMode.Left
                    If (ComboBoxInvert.SelectedIndex = 0) Then
                        '矩形 → 円形
                        '矩形領域の基準座標
                        m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint(m_SrcImage.Window.X, m_SrcImage.Window.Y)
                        TextBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0")
                        TextBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0")
                        '円形領域の回転中心座標
                        m_PolarTransParam.OriginOut = New FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Width)
                        TextBoxOriginOutX.Text = m_SrcImage.Window.Width.ToString("0.0")
                        TextBoxOriginOutY.Text = m_SrcImage.Window.Width.ToString("0.0")
                        '円形領域の半径
                        m_PolarTransParam.Radius = m_SrcImage.Window.Width
                        NumericUpDownRadius.Value = m_SrcImage.Window.Width
                    Else
                        '円形 → 矩形
                        '矩形領域の基準座標
                        m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint(m_SrcImage.Window.X, m_SrcImage.Window.Y)
                        TextBoxOriginInX.Text = m_SrcImage.Window.X.ToString("0.0")
                        TextBoxOriginInY.Text = m_SrcImage.Window.Y.ToString("0.0")
                    End If
                Case 3
                    'Right(右下)
                    m_PolarTrans.Param.CoordinateMode = FVIL.PolarTrans.CoordinateMode.Right
                    If (ComboBoxInvert.SelectedIndex = 0) Then
                        '矩形 → 円形
                        '矩形領域の基準座標
                        m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Height)
                        TextBoxOriginInX.Text = m_SrcImage.Window.Width.ToString("0.0")
                        TextBoxOriginInY.Text = m_SrcImage.Window.Height.ToString("0.0")
                        '円形領域の回転中心座標
                        m_PolarTransParam.OriginOut = New FVIL.Data.CFviPoint(m_SrcImage.Window.Width, m_SrcImage.Window.Width)
                        TextBoxOriginOutX.Text = m_SrcImage.Window.Width.ToString("0.0")
                        TextBoxOriginOutY.Text = m_SrcImage.Window.Width.ToString("0.0")
                        '円形領域の半径
                        m_PolarTransParam.Radius = m_SrcImage.Window.Width
                        NumericUpDownRadius.Value = m_SrcImage.Window.Width
                    Else
                        '円形 → 矩形
                        '矩形領域の基準座標
                        m_PolarTransParam.OriginIn = New FVIL.Data.CFviPoint((m_SrcImage.Window.Width / 2), (m_SrcImage.Window.Width / 2))
                        TextBoxOriginInX.Text = (m_SrcImage.Window.Width / 2).ToString("0.0")
                        TextBoxOriginInY.Text = (m_SrcImage.Window.Width / 2).ToString("0.0")
                    End If
            End Select

            If (ComboBoxInvert.SelectedIndex = 0) Then
                '矩形 → 円形
                '矩形領域サイズ
                m_PolarTransParam.Width = m_SrcImage.Window.Width
                NumericUpDownWidth.Value = m_SrcImage.Window.Width
                m_PolarTransParam.Height = m_SrcImage.Window.Height
                NumericUpDownHeight.Value = m_SrcImage.Window.Height
            Else
                '円形 → 矩形
                '矩形領域サイズ
                m_PolarTransParam.Width = (m_SrcImage.Window.Width / 2)
                NumericUpDownWidth.Value = (m_SrcImage.Window.Width / 2)
                m_PolarTransParam.Height = (m_SrcImage.Window.Height / 2)
                NumericUpDownHeight.Value = (m_SrcImage.Window.Height / 2)
                '円形領域の回転中心座標
                m_PolarTransParam.OriginOut = New FVIL.Data.CFviPoint((m_SrcImage.Window.Width / 2), (m_SrcImage.Window.Height / 2))
                TextBoxOriginOutX.Text = (m_SrcImage.Window.Width / 2).ToString("0.0")
                TextBoxOriginOutY.Text = (m_SrcImage.Window.Height / 2).ToString("0.0")
                '円形領域の半径
                m_PolarTransParam.Radius = (m_SrcImage.Window.Width / 2)
                NumericUpDownRadius.Value = (m_SrcImage.Window.Width / 2)
            End If
        Catch ex As FVIL.CFviException
            'エラー処理
            MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        Catch ex As Exception
            'エラー処理
            MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
    End Sub

    ''' <summary>
    ''' 矩形領域の基準座標
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 矩形領域の基準座標（X座標）の設定。
    ''' </remarks>
    Private Sub TextBoxOriginInX_TextChanged(sender As Object, e As EventArgs) Handles TextBoxOriginInX.TextChanged
        Try
            Dim Point As FVIL.Data.CFviPoint = New FVIL.Data.CFviPoint()
            Point.X = Double.Parse(TextBoxOriginInX.Text)
            Point.Y = m_PolarTransParam.OriginIn.Y
            m_PolarTransParam.OriginIn = Point
        Catch ex As FVIL.CFviException
            'エラー処理
            MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        Catch ex As Exception
            'エラー処理
            MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
    End Sub

    ''' <summary>
    ''' 矩形領域の基準座標
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 矩形領域の基準座標（Y座標）の設定。
    ''' </remarks>
    Private Sub TextBoxOriginInY_TextChanged(sender As Object, e As EventArgs) Handles TextBoxOriginInY.TextChanged
        Try
            Dim Point As FVIL.Data.CFviPoint = New FVIL.Data.CFviPoint()
            Point.X = m_PolarTransParam.OriginIn.X
            Point.Y = Double.Parse(TextBoxOriginInY.Text)
            m_PolarTransParam.OriginIn = Point
        Catch ex As FVIL.CFviException
            'エラー処理
            MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        Catch ex As Exception
            'エラー処理
            MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
    End Sub

    ''' <summary>
    ''' 矩形領域サイズ
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 矩形領域サイズ（幅）の設定。
    ''' </remarks>
    Private Sub NumericUpDownWidth_ValueChanged(sender As Object, e As EventArgs) Handles NumericUpDownWidth.ValueChanged
        Try
            m_PolarTransParam.Width = NumericUpDownWidth.Value
        Catch ex As FVIL.CFviException
            'エラー処理
            MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        Catch ex As Exception
            'エラー処理
            MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
    End Sub

    ''' <summary>
    ''' 矩形領域サイズ
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 矩形領域サイズ（高さ）の設定。
    ''' </remarks>
    Private Sub NumericUpDownHeight_ValueChanged(sender As Object, e As EventArgs) Handles NumericUpDownHeight.ValueChanged
        Try
            m_PolarTransParam.Height = NumericUpDownHeight.Value
        Catch ex As FVIL.CFviException
            'エラー処理
            MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        Catch ex As Exception
            'エラー処理
            MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
    End Sub

    ''' <summary>
    ''' 円形領域の回転中心座標
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 円形領域の回転中心座標（X座標）の設定。
    ''' </remarks>
    Private Sub TextBoxOriginOutX_TextChanged(sender As Object, e As EventArgs) Handles TextBoxOriginOutX.TextChanged
        Try
            Dim Point As FVIL.Data.CFviPoint = New FVIL.Data.CFviPoint()
            Point.X = Double.Parse(TextBoxOriginOutX.Text)
            Point.Y = m_PolarTransParam.OriginOut.Y
            m_PolarTransParam.OriginOut = Point
        Catch ex As FVIL.CFviException
            'エラー処理
            MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        Catch ex As Exception
            'エラー処理
            MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
    End Sub

    ''' <summary>
    ''' 円形領域の回転中心座標
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 円形領域の回転中心座標（Y座標）の設定。
    ''' </remarks>
    Private Sub TextBoxOriginOutY_TextChanged(sender As Object, e As EventArgs) Handles TextBoxOriginOutY.TextChanged
        Try
            Dim Point As FVIL.Data.CFviPoint = New FVIL.Data.CFviPoint()
            Point.X = m_PolarTransParam.OriginOut.X
            Point.Y = Double.Parse(TextBoxOriginOutY.Text)
            m_PolarTransParam.OriginOut = Point
        Catch ex As FVIL.CFviException
            'エラー処理
            MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        Catch ex As Exception
            'エラー処理
            MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
    End Sub

    ''' <summary>
    ''' 円形領域の半径
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 円形領域の半径の設定。
    ''' </remarks>
    Private Sub NumericUpDownRadius_ValueChanged(sender As Object, e As EventArgs) Handles NumericUpDownRadius.ValueChanged
        Try
            m_PolarTransParam.Radius = NumericUpDownRadius.Value
        Catch ex As FVIL.CFviException
            'エラー処理
            MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        Catch ex As Exception
            'エラー処理
            MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
    End Sub

    ''' <summary>
    ''' 円形領域の回転開始角度
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 円形領域の回転開始角度の設定。
    ''' </remarks>
    Private Sub TextBoxStartAngle_TextChanged(sender As Object, e As EventArgs) Handles TextBoxStartAngle.TextChanged
        Try
            If (Double.Parse(TextBoxStartAngle.Text) < 0) Then
                TextBoxStartAngle.Text = "0.0"
                m_PolarTransParam.StartAngle = New FVIL.Data.CFviAngle(0.0)
            ElseIf (Double.Parse(TextBoxStartAngle.Text) >= 359.9) Then
                TextBoxStartAngle.Text = "359.9"
                m_PolarTransParam.StartAngle = New FVIL.Data.CFviAngle(359.9)
            Else
                m_PolarTransParam.StartAngle = New FVIL.Data.CFviAngle(Double.Parse(TextBoxStartAngle.Text))
            End If
        Catch ex As FVIL.CFviException
            'エラー処理
            MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        Catch ex As Exception
            'エラー処理
            MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
    End Sub

    ''' <summary>
    ''' 円形領域の回転範囲
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 円形領域の回転範囲。
    ''' </remarks>
    Private Sub TextBoxRangeAngle_TextChanged(sender As Object, e As EventArgs) Handles TextBoxRangeAngle.TextChanged
        Try
            If (Double.Parse(TextBoxRangeAngle.Text) < -360.0) Then
                TextBoxRangeAngle.Text = "-360.0"
                m_PolarTransParam.RangeAngle = New FVIL.Data.CFviAngle(-360.0)
            ElseIf (Double.Parse(TextBoxRangeAngle.Text) > 360.0) Then
                TextBoxRangeAngle.Text = "360.0"
                m_PolarTransParam.RangeAngle = New FVIL.Data.CFviAngle(360.0)
            Else
                m_PolarTransParam.RangeAngle = New FVIL.Data.CFviAngle(Double.Parse(TextBoxRangeAngle.Text))
            End If
        Catch ex As FVIL.CFviException
            'エラー処理
            MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        Catch ex As Exception
            'エラー処理
            MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
    End Sub

    ''' <summary>
    ''' x１ボタン
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 等倍で表示します。
    ''' </remarks>
    Private Sub ButtonMag1_Click(sender As Object, e As EventArgs) Handles ButtonMag1.Click
        '画像の表示倍率の取得または設定を行います。1.0と指定すると等倍で表示します。
        '倍率値は、0.5とした場合は、幅・高さ共に1/2となり、面積が1/4になります。
        '3.0とした場合は、幅・高さ共に3倍となり、面積が9倍になります。

        '表示倍率の設定
        CFviImageView1.Display.Magnification = 1.0
        '再描画
        CFviImageView1.Refresh()
    End Sub

    ''' <summary>
    ''' Fitボタン
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 画像全体がビューのクライアント領域に表示できるように表示倍率を縮小(または拡大)します。
    ''' </remarks>
    Private Sub ButtonFit_Click(sender As Object, e As EventArgs) Handles ButtonFit.Click
        '表示倍率の設定
        CFviImageView1.FitImageSize()
        '再描画
        CFviImageView1.Refresh()
    End Sub

    ''' <summary>
    ''' ＋ボタン
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 現在の倍率に0.5加えた倍率で表示します。
    ''' </remarks>
    Private Sub ButtonPlus_Click(sender As Object, e As EventArgs) Handles ButtonPlus.Click
        Dim Value As Double = 0
        '現倍率の取得
        Value = CFviImageView1.Display.Magnification
        '表示倍率の設定
        Value = Value + 0.5
        CFviImageView1.Display.Magnification = Value
        '再描画
        CFviImageView1.Refresh()
    End Sub

    ''' <summary>
    ''' －ボタン
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 現在の倍率から0.5引いた倍率で表示します。ただし、倍率が０以下になる場合は倍率0.1で表示します。
    ''' </remarks>
    Private Sub ButtonMinus_Click(sender As Object, e As EventArgs) Handles ButtonMinus.Click
        Dim Value As Double = 0
        '現倍率の取得
        Value = CFviImageView1.Display.Magnification
        '表示倍率の設定
        Value = Value - 0.5
        If (Value <= 0) Then
            '0以下を設定するとエラーになるので0.1を設定する
            Value = 0.1
        End If
        '表示倍率の設定
        CFviImageView1.Display.Magnification = Value
        '再描画
        CFviImageView1.Refresh()
    End Sub

    ''' <summary>
    ''' Ascopeチェックボックス
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' ASCOPEの表示を切替えます。
    ''' </remarks>
    Private Sub CheckBoxAscope_CheckedChanged(sender As Object, e As EventArgs) Handles CheckBoxAscope.CheckedChanged
        'ASCOPEオーバレイの設定
        If (CheckBoxAscope.Checked) Then
            'ASCOPEの表示を有効にする。
            CFviImageView1.Display.OverlayAscope.Active = True
        Else
            'ASCOPEの表示を無効にする。
            CFviImageView1.Display.OverlayAscope.Active = False
        End If
        '再描画
        CFviImageView1.Refresh()
    End Sub

End Class
